@@ -34,6 +34,7 @@ from watchdog.events import (
     DirCreatedEvent,
     DirMovedEvent,
     FileClosedEvent,
+    FileOpenedEvent,
 )
 from watchdog.observers.api import ObservedWatch
 
@@ -122,6 +123,9 @@ def test_create():
         expect_event(DirModifiedEvent(p()))
 
     if platform.is_linux():
+        event = event_queue.get(timeout=5)[0]
+        assert event.src_path == p('a')
+        assert isinstance(event, FileOpenedEvent)
         event = event_queue.get(timeout=5)[0]
         assert event.src_path == p('a')
         assert isinstance(event, FileClosedEvent)
@@ -143,7 +147,7 @@ def test_close():
     assert os.path.normpath(event.src_path) == os.path.normpath(p(''))
     assert isinstance(event, DirModifiedEvent)
 
-    # After read-only, only IN_CLOSE_NOWRITE is emitted but not catched for now #747
+    # After read-only, only IN_CLOSE_NOWRITE is emitted but not caught for now #747
     open(p('a'), 'r').close()
 
     assert event_queue.empty()
@@ -188,6 +192,11 @@ def test_modify():
 
     touch(p('a'))
 
+    if platform.is_linux():
+        event = event_queue.get(timeout=5)[0]
+        assert event.src_path == p('a')
+        assert isinstance(event, FileOpenedEvent)
+
     expect_event(FileModifiedEvent(p('a')))
 
     if platform.is_linux():
@@ -355,6 +364,7 @@ def test_separate_consecutive_moves():
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
+@pytest.mark.skipif(platform.is_bsd(), reason="BSD create another set of events for this test")
 def test_delete_self():
     mkdir(p('dir1'))
     start_watching(p('dir1'))
@@ -428,6 +438,11 @@ def test_recursive_on():
         assert event.src_path == p('dir1', 'dir2', 'dir3')
         assert isinstance(event, DirModifiedEvent)
 
+        if platform.is_linux():
+            event = event_queue.get(timeout=5)[0]
+            assert event.src_path == p('dir1', 'dir2', 'dir3', 'a')
+            assert isinstance(event, FileOpenedEvent)
+
         if not platform.is_bsd():
             event = event_queue.get(timeout=5)[0]
             assert event.src_path == p('dir1', 'dir2', 'dir3', 'a')
@@ -449,6 +464,7 @@ def test_recursive_off():
         expect_event(DirModifiedEvent(p()))
 
         if platform.is_linux():
+            expect_event(FileOpenedEvent(p('b')))
             expect_event(FileClosedEvent(p('b')))
 
     # currently limiting these additional events to macOS only, see https://github.com/gorakhargosh/watchdog/pull/779
@@ -504,7 +520,8 @@ def test_renaming_top_level_directory():
         if event_queue.empty():
             break
 
-    assert all([isinstance(e, (FileCreatedEvent, FileMovedEvent, DirModifiedEvent, FileClosedEvent)) for e in events])
+    assert all([isinstance(e, (FileCreatedEvent, FileMovedEvent, FileOpenedEvent, DirModifiedEvent, FileClosedEvent))
+                for e in events])
 
     for event in events:
         if isinstance(event, FileCreatedEvent):
@@ -594,6 +611,11 @@ def test_move_nested_subdirectories():
 
     touch(p('dir2/dir3', 'a'))
 
+    if platform.is_linux():
+        event = event_queue.get(timeout=5)[0]
+        assert event.src_path == p('dir2/dir3', 'a')
+        assert isinstance(event, FileOpenedEvent)
+
     event = event_queue.get(timeout=5)[0]
     assert event.src_path == p('dir2/dir3', 'a')
     assert isinstance(event, FileModifiedEvent)
@@ -642,6 +664,7 @@ def test_move_nested_subdirectories_on_windows():
 
 
 @pytest.mark.flaky(max_runs=5, min_passes=1, rerun_filter=rerun_filter)
+@pytest.mark.skipif(platform.is_bsd(), reason="BSD create another set of events for this test")
 def test_file_lifecyle():
     start_watching()
 
@@ -656,8 +679,10 @@ def test_file_lifecyle():
         expect_event(DirModifiedEvent(p()))
 
     if platform.is_linux():
+        expect_event(FileOpenedEvent(p('a')))
         expect_event(FileClosedEvent(p('a')))
         expect_event(DirModifiedEvent(p()))
+        expect_event(FileOpenedEvent(p('a')))
 
     expect_event(FileModifiedEvent(p('a')))
 
